# Reporting a Bug

Bloqade is currently in the **alpha** phase of development, meaning bugs most likely exist in the
current implementation. We are continuously striving to
improve the stability of Bloqade. As such, we encourage
our users to report all bugs they find. To do this, we
ask you to submit an issue to our GitHub page:
https://github.com/QuEraComputing/bloqade-analog/issues

Please include the following information in your bug report:

1. A short, descriptive title.

2. A detailed description of the bug, including the
expected behavior and what happened.

3. A minimal code example that reproduces the bug.

4. The version of Bloqade you are using.

5. The version of Python you are using.

6. The version of your operating system.
